# Changelog

## 0.18.3 (2025-06-18)

Full Changelog: [v0.18.2...v0.18.3](https://github.com/lastmile-ai/lastmile-python/compare/v0.18.2...v0.18.3)

### Bug Fixes

* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([4d686d5](https://github.com/lastmile-ai/lastmile-python/commit/4d686d56d838296cbc691c744719af525d6da607))


### Chores

* **readme:** update badges ([2b59733](https://github.com/lastmile-ai/lastmile-python/commit/2b5973376f05d5ab720fbd2f90512135791e933c))

## 0.18.2 (2025-06-17)

Full Changelog: [v0.18.1...v0.18.2](https://github.com/lastmile-ai/lastmile-python/compare/v0.18.1...v0.18.2)

### Chores

* **ci:** enable for pull requests ([50c94a7](https://github.com/lastmile-ai/lastmile-python/commit/50c94a73a9beea1e98ff06d3c43143b95d626012))
* **internal:** update conftest.py ([661342e](https://github.com/lastmile-ai/lastmile-python/commit/661342ea1f88f6b9b24d5178f273fa9a2b80b96d))
* **tests:** add tests for httpx client instantiation & proxies ([5bb061a](https://github.com/lastmile-ai/lastmile-python/commit/5bb061a3077b5e0e84650b45d3642eee32db0105))

## 0.18.1 (2025-06-13)

Full Changelog: [v0.18.0...v0.18.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.18.0...v0.18.1)

### Bug Fixes

* **client:** correctly parse binary response | stream ([6a5555e](https://github.com/lastmile-ai/lastmile-python/commit/6a5555ed7bc800388ce1ac309162f8a25b4bee8e))


### Chores

* **tests:** run tests in parallel ([2aae175](https://github.com/lastmile-ai/lastmile-python/commit/2aae1754783f6e89dd4b8db38283cda9a533a399))

## 0.18.0 (2025-06-03)

Full Changelog: [v0.17.2...v0.18.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.17.2...v0.18.0)

### Features

* **client:** add follow_redirects request option ([7e382ae](https://github.com/lastmile-ai/lastmile-python/commit/7e382ae37e9f58d54262e8d66d4baf9eaff45818))


### Chores

* **docs:** remove reference to rye shell ([a70c11a](https://github.com/lastmile-ai/lastmile-python/commit/a70c11ac59d45000a465109d191845924b305025))

## 0.17.2 (2025-05-22)

Full Changelog: [v0.17.1...v0.17.2](https://github.com/lastmile-ai/lastmile-python/compare/v0.17.1...v0.17.2)

### Chores

* **docs:** grammar improvements ([0e4cfeb](https://github.com/lastmile-ai/lastmile-python/commit/0e4cfebc70790cd920dc5e440d8a7d437285a990))

## 0.17.1 (2025-05-16)

Full Changelog: [v0.17.0...v0.17.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.17.0...v0.17.1)

### Chores

* **ci:** fix installation instructions ([49d22bd](https://github.com/lastmile-ai/lastmile-python/commit/49d22bd1b5459f07db3f25f890e650e832269853))
* **ci:** upload sdks to package manager ([4d450a4](https://github.com/lastmile-ai/lastmile-python/commit/4d450a410836f082baa2cbd400cec868e42ee908))

## 0.17.0 (2025-05-14)

Full Changelog: [v0.16.0...v0.17.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.16.0...v0.17.0)

### Features

* **api:** api update ([55237f6](https://github.com/lastmile-ai/lastmile-python/commit/55237f6b1f43146580cf2da44bcd4c503f3e5b33))

## 0.16.0 (2025-05-14)

Full Changelog: [v0.15.1...v0.16.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.15.1...v0.16.0)

### Features

* **api:** api update ([5cfcda0](https://github.com/lastmile-ai/lastmile-python/commit/5cfcda08c2aaff013550e0c99774c8aed0599a05))

## 0.15.1 (2025-05-10)

Full Changelog: [v0.15.0...v0.15.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.15.0...v0.15.1)

### Bug Fixes

* **package:** support direct resource imports ([463f999](https://github.com/lastmile-ai/lastmile-python/commit/463f999a3b99cbbd511881031535aaffc5c742fa))


### Chores

* **internal:** avoid errors for isinstance checks on proxies ([bd6e863](https://github.com/lastmile-ai/lastmile-python/commit/bd6e8638c1d1e13e39cac350eec3a2a03c255404))
* use lazy imports for resources ([7179944](https://github.com/lastmile-ai/lastmile-python/commit/7179944c7e78ef0b87ba69f2eb6d89270280eded))

## 0.15.0 (2025-05-03)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.14.0...v0.15.0)

### Features

* **api:** api update ([2d03080](https://github.com/lastmile-ai/lastmile-python/commit/2d03080439b2af58424934124f9b5c834bc1f90c))

## 0.14.0 (2025-05-02)

Full Changelog: [v0.13.0...v0.14.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.13.0...v0.14.0)

### Features

* **api:** api update ([97c4f19](https://github.com/lastmile-ai/lastmile-python/commit/97c4f1977ac6382064395172e6b8ed6ee8e09d44))

## 0.13.0 (2025-04-28)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.12.0...v0.13.0)

### Features

* **api:** api update ([588ec48](https://github.com/lastmile-ai/lastmile-python/commit/588ec48b90681efd5300f9d3997cf447f74eed6a))
* **api:** api update ([40d2dee](https://github.com/lastmile-ai/lastmile-python/commit/40d2dee2c0747f4fd7382368cc9bcf22736e18bd))
* **api:** api update ([a61c087](https://github.com/lastmile-ai/lastmile-python/commit/a61c087ab01be829a28865e6c68e5f013eab126c))


### Bug Fixes

* **pydantic v1:** more robust ModelField.annotation check ([33bff9b](https://github.com/lastmile-ai/lastmile-python/commit/33bff9b18f439752f52ba22240097e47be42234b))


### Chores

* broadly detect json family of content-type headers ([4993315](https://github.com/lastmile-ai/lastmile-python/commit/499331555561f83ee872e8fd3ebd09b1553b439d))
* **ci:** add timeout thresholds for CI jobs ([84c90ba](https://github.com/lastmile-ai/lastmile-python/commit/84c90bab6788894851e375e2ce370856e648e776))
* **ci:** only use depot for staging repos ([830575c](https://github.com/lastmile-ai/lastmile-python/commit/830575cf415f17559c8853219214cea360089ee0))
* **internal:** codegen related update ([3e04ac6](https://github.com/lastmile-ai/lastmile-python/commit/3e04ac6d7ef20f70e714d0b1958de1294d88dfe1))
* **internal:** fix list file params ([718c599](https://github.com/lastmile-ai/lastmile-python/commit/718c599b55ffaa518628793534fad58aa5aeaefc))
* **internal:** import reformatting ([ef46d0c](https://github.com/lastmile-ai/lastmile-python/commit/ef46d0c1ba40e945bea8fc59646ce9ed64110501))
* **internal:** minor formatting changes ([3ba776c](https://github.com/lastmile-ai/lastmile-python/commit/3ba776c950a4912dc7a436427b57b3b8b2993a24))
* **internal:** refactor retries to not use recursion ([139ac1e](https://github.com/lastmile-ai/lastmile-python/commit/139ac1eda29766b0b3a4c3e465a5d053e013e010))
* **internal:** update models test ([4e7791e](https://github.com/lastmile-ai/lastmile-python/commit/4e7791ee4e06719257837bf3d1028cdf69c89824))

## 0.12.0 (2025-04-18)

Full Changelog: [v0.11.4...v0.12.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.11.4...v0.12.0)

### Features

* **api:** api update ([91b2b80](https://github.com/lastmile-ai/lastmile-python/commit/91b2b80f330e005d27a89af6efbe0e3ca6f94977))
* **api:** manual updates ([#218](https://github.com/lastmile-ai/lastmile-python/issues/218)) ([e025f4b](https://github.com/lastmile-ai/lastmile-python/commit/e025f4bc3fd2f76fbf98119cfe59895e4a832294))
* **api:** manual updates ([#220](https://github.com/lastmile-ai/lastmile-python/issues/220)) ([88bba93](https://github.com/lastmile-ai/lastmile-python/commit/88bba9374808ccd12bab06624cd2dc706a4a0276))


### Bug Fixes

* **perf:** optimize some hot paths ([01c94d8](https://github.com/lastmile-ai/lastmile-python/commit/01c94d8476108a74a20dac664f4f2126c066e271))
* **perf:** skip traversing types for NotGiven values ([d0ce6df](https://github.com/lastmile-ai/lastmile-python/commit/d0ce6df5c85fc87e2002389d0300fcbf8b42f8d3))
* pluralize `list` response variables ([97b7433](https://github.com/lastmile-ai/lastmile-python/commit/97b7433a166ab2cb795666087864c74bc37e1d3a))


### Chores

* **client:** minor internal fixes ([7587fdb](https://github.com/lastmile-ai/lastmile-python/commit/7587fdb76dd4dea38cac02b29e7106a5725fc2a4))
* go live ([0e3f90e](https://github.com/lastmile-ai/lastmile-python/commit/0e3f90ef238b0933a4bae8e15bf1fd6f14c8ebcb))
* **internal:** base client updates ([96c7853](https://github.com/lastmile-ai/lastmile-python/commit/96c78537de15a07f7a953d3242d142cc8e0b717e))
* **internal:** bump pyright version ([05537db](https://github.com/lastmile-ai/lastmile-python/commit/05537db45be4becdcb306bd7966192e1021d1430))
* **internal:** codegen related update ([efdc764](https://github.com/lastmile-ai/lastmile-python/commit/efdc764d95fee8925925f823f5ca664d8be6eb82))
* **internal:** expand CI branch coverage ([7c819a2](https://github.com/lastmile-ai/lastmile-python/commit/7c819a25e957a59961aa2d204bdf1046a41d0933))
* **internal:** reduce CI branch coverage ([7bcc12c](https://github.com/lastmile-ai/lastmile-python/commit/7bcc12c398feb66b13513416cacba349370be0e8))
* **internal:** remove trailing character ([4c86b15](https://github.com/lastmile-ai/lastmile-python/commit/4c86b154a1f2f77afda01854bec21413706822c7))
* **internal:** slight transform perf improvement ([5cd6c5e](https://github.com/lastmile-ai/lastmile-python/commit/5cd6c5eac48ea633faf45e7449f2f764cd30e0e8))
* **internal:** update pyright settings ([f2011fa](https://github.com/lastmile-ai/lastmile-python/commit/f2011fa8f4c05c907e77a8640d9811daf80fbf1e))


### Documentation

* swap examples used in readme ([13db398](https://github.com/lastmile-ai/lastmile-python/commit/13db39867f56fb6139baa6f028a7675bb353e4f8))

## 0.11.4 (2025-03-17)

Full Changelog: [v0.11.3...v0.11.4](https://github.com/lastmile-ai/lastmile-python/compare/v0.11.3...v0.11.4)

### Bug Fixes

* **ci:** ensure pip is always available ([#214](https://github.com/lastmile-ai/lastmile-python/issues/214)) ([ade1056](https://github.com/lastmile-ai/lastmile-python/commit/ade1056c92e053c8bd88460772c9df9173f170dc))
* **types:** handle more discriminated union shapes ([#213](https://github.com/lastmile-ai/lastmile-python/issues/213)) ([a679182](https://github.com/lastmile-ai/lastmile-python/commit/a67918238665e14a26d3bf416bae4ec346fbbe21))


### Chores

* **internal:** bump rye to 0.44.0 ([#211](https://github.com/lastmile-ai/lastmile-python/issues/211)) ([4cb7b1a](https://github.com/lastmile-ai/lastmile-python/commit/4cb7b1ac39bc0d34e9a14bfec93229a5ccf2b3a8))

## 0.11.3 (2025-03-14)

Full Changelog: [v0.11.2...v0.11.3](https://github.com/lastmile-ai/lastmile-python/compare/v0.11.2...v0.11.3)

### Chores

* **internal:** remove extra empty newlines ([#208](https://github.com/lastmile-ai/lastmile-python/issues/208)) ([7c8e37e](https://github.com/lastmile-ai/lastmile-python/commit/7c8e37ece7b4dcd2864d7970ddb89705cc3c6580))

## 0.11.2 (2025-03-12)

Full Changelog: [v0.11.1...v0.11.2](https://github.com/lastmile-ai/lastmile-python/compare/v0.11.1...v0.11.2)

### Chores

* **internal:** codegen related update ([#205](https://github.com/lastmile-ai/lastmile-python/issues/205)) ([82792ea](https://github.com/lastmile-ai/lastmile-python/commit/82792ea86d88fc47e07bcb2ae312133bb2ae8bd0))

## 0.11.1 (2025-03-11)

Full Changelog: [v0.11.0...v0.11.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.11.0...v0.11.1)

### Documentation

* revise readme docs about nested params ([#202](https://github.com/lastmile-ai/lastmile-python/issues/202)) ([90c4f8f](https://github.com/lastmile-ai/lastmile-python/commit/90c4f8f267ee52db16718237cf1631ea039f4fdb))

## 0.11.0 (2025-03-06)

Full Changelog: [v0.10.2...v0.11.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.10.2...v0.11.0)

### Features

* [LAS-1649][1/n] Python SDK Cleanup -- Datasets ([866baff](https://github.com/lastmile-ai/lastmile-python/commit/866baff806d5efdc4dcf1f461d027146d80f27d0))
* [LAS-1649][2/2] Python SDK Cleanup - Evals ([0a88bc6](https://github.com/lastmile-ai/lastmile-python/commit/0a88bc68f3f749b57906a59938fd0c5930f5f5ae))
* [LAS-1656] Support Timeout Propagation in Python SDK ([b1bf855](https://github.com/lastmile-ai/lastmile-python/commit/b1bf8555979ccc5c4589b42c1a11c173cd710ef0))

## 0.10.2 (2025-03-04)

Full Changelog: [v0.10.1...v0.10.2](https://github.com/lastmile-ai/lastmile-python/compare/v0.10.1...v0.10.2)

### Chores

* **internal:** remove unused http client options forwarding ([#194](https://github.com/lastmile-ai/lastmile-python/issues/194)) ([7e6bcbc](https://github.com/lastmile-ai/lastmile-python/commit/7e6bcbc545ac3e2cd2a37ab09428b6d684cfe232))

## 0.10.1 (2025-02-28)

Full Changelog: [v0.10.0...v0.10.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.10.0...v0.10.1)

### Chores

* **docs:** update client docstring ([#191](https://github.com/lastmile-ai/lastmile-python/issues/191)) ([78c9e63](https://github.com/lastmile-ai/lastmile-python/commit/78c9e63ca391dc2fd233a3245ced81653cf54c4e))


### Documentation

* update URLs from stainlessapi.com to stainless.com ([#190](https://github.com/lastmile-ai/lastmile-python/issues/190)) ([738c090](https://github.com/lastmile-ai/lastmile-python/commit/738c09058ab79347665c1447c6c7e58e4170e532))

## 0.10.0 (2025-02-27)

Full Changelog: [v0.9.2...v0.10.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.9.2...v0.10.0)

### Features

* **api:** api update ([#187](https://github.com/lastmile-ai/lastmile-python/issues/187)) ([25e8357](https://github.com/lastmile-ai/lastmile-python/commit/25e835777364d95e009a3a42aef6bebe50c5867a))

## 0.9.2 (2025-02-26)

Full Changelog: [v0.9.1...v0.9.2](https://github.com/lastmile-ai/lastmile-python/compare/v0.9.1...v0.9.2)

### Chores

* **internal:** properly set __pydantic_private__ ([#183](https://github.com/lastmile-ai/lastmile-python/issues/183)) ([7bd1081](https://github.com/lastmile-ai/lastmile-python/commit/7bd108177df6076eb275727af746a059c1add336))

## 0.9.1 (2025-02-25)

Full Changelog: [v0.9.0...v0.9.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.9.0...v0.9.1)

### Chores

* **internal:** fix devcontainers setup ([#180](https://github.com/lastmile-ai/lastmile-python/issues/180)) ([c3e7c88](https://github.com/lastmile-ai/lastmile-python/commit/c3e7c88e51fb1142b3b20aa038b4f80a1752b44b))

## 0.9.0 (2025-02-21)

Full Changelog: [v0.8.1...v0.9.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.8.1...v0.9.0)

### Features

* **client:** allow passing `NotGiven` for body ([#177](https://github.com/lastmile-ai/lastmile-python/issues/177)) ([597aeda](https://github.com/lastmile-ai/lastmile-python/commit/597aeda42067471ec10184b18c79a73b6ac19895))


### Bug Fixes

* **client:** mark some request bodies as optional ([597aeda](https://github.com/lastmile-ai/lastmile-python/commit/597aeda42067471ec10184b18c79a73b6ac19895))

## 0.8.1 (2025-02-18)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.8.0...v0.8.1)

### Bug Fixes

* asyncify on non-asyncio runtimes ([#174](https://github.com/lastmile-ai/lastmile-python/issues/174)) ([368c588](https://github.com/lastmile-ai/lastmile-python/commit/368c588e433a0616da08f37ac5471bad9c4489d9))


### Chores

* **internal:** update client tests ([#172](https://github.com/lastmile-ai/lastmile-python/issues/172)) ([23c581d](https://github.com/lastmile-ai/lastmile-python/commit/23c581db99657fa0dfa14333b7203dc8eb03b666))
* **internal:** update client tests ([#175](https://github.com/lastmile-ai/lastmile-python/issues/175)) ([5af9c25](https://github.com/lastmile-ai/lastmile-python/commit/5af9c25d0bed7591d793c9603656fa23e52a2ae0))

## 0.8.0 (2025-02-10)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.7.0...v0.8.0)

### Features

* **api:** api update ([#158](https://github.com/lastmile-ai/lastmile-python/issues/158)) ([4c19b9f](https://github.com/lastmile-ai/lastmile-python/commit/4c19b9f25cd1062582d24d883ca5c90595efc1ef))
* **api:** api update ([#161](https://github.com/lastmile-ai/lastmile-python/issues/161)) ([9bcb5d0](https://github.com/lastmile-ai/lastmile-python/commit/9bcb5d0fc8d6edc555ef954cd716a70f9dfc83f2))
* **api:** api update ([#166](https://github.com/lastmile-ai/lastmile-python/issues/166)) ([67ae889](https://github.com/lastmile-ai/lastmile-python/commit/67ae8892f6433abd706be89653b20649d9dff9ab))
* **api:** api update ([#167](https://github.com/lastmile-ai/lastmile-python/issues/167)) ([dd5339c](https://github.com/lastmile-ai/lastmile-python/commit/dd5339ce07ed239fd7dcda7ad28ab3daecf31804))
* **client:** send `X-Stainless-Read-Timeout` header ([#163](https://github.com/lastmile-ai/lastmile-python/issues/163)) ([220bc73](https://github.com/lastmile-ai/lastmile-python/commit/220bc7327d2a03d3835b59204a0ae17e1ceeb7dd))


### Chores

* **internal:** fix type traversing dictionary params ([#164](https://github.com/lastmile-ai/lastmile-python/issues/164)) ([6999849](https://github.com/lastmile-ai/lastmile-python/commit/6999849e097e948408098296d31237eb46bed7f9))
* **internal:** minor type handling changes ([#165](https://github.com/lastmile-ai/lastmile-python/issues/165)) ([7d99dde](https://github.com/lastmile-ai/lastmile-python/commit/7d99dde2aa37cdabd5f01e9a2ead1e97e33b2b04))

## 0.7.0 (2025-02-04)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.6.0...v0.7.0)

### Features

* **api:** api update ([#145](https://github.com/lastmile-ai/lastmile-python/issues/145)) ([b424bbb](https://github.com/lastmile-ai/lastmile-python/commit/b424bbb7be381ef205f6fe7c0b5ccdf2e47e822c))
* **api:** api update ([#146](https://github.com/lastmile-ai/lastmile-python/issues/146)) ([1d0a323](https://github.com/lastmile-ai/lastmile-python/commit/1d0a3236edc8413e266d65a0f8a0dee2cb22ef30))
* **api:** api update ([#147](https://github.com/lastmile-ai/lastmile-python/issues/147)) ([36f93b4](https://github.com/lastmile-ai/lastmile-python/commit/36f93b4b3a7cf5bcd36f69439297a18851989f89))
* **api:** api update ([#148](https://github.com/lastmile-ai/lastmile-python/issues/148)) ([d3fca45](https://github.com/lastmile-ai/lastmile-python/commit/d3fca45cef404b65144136fb16552c8eedf1cfaa))
* **api:** api update ([#149](https://github.com/lastmile-ai/lastmile-python/issues/149)) ([e648629](https://github.com/lastmile-ai/lastmile-python/commit/e6486294e4aad2bbcc6ea4db8e8f855c6a312f3f))
* **api:** api update ([#150](https://github.com/lastmile-ai/lastmile-python/issues/150)) ([df8fcdc](https://github.com/lastmile-ai/lastmile-python/commit/df8fcdc872fe8c9ccf086eb92cacaa3502dd76cc))
* **api:** api update ([#151](https://github.com/lastmile-ai/lastmile-python/issues/151)) ([3f106cb](https://github.com/lastmile-ai/lastmile-python/commit/3f106cb548f618284ad214d11d64d1ab2ee03f3d))
* **api:** api update ([#152](https://github.com/lastmile-ai/lastmile-python/issues/152)) ([c82cf36](https://github.com/lastmile-ai/lastmile-python/commit/c82cf36dfcb8d5ce8926394cb0b8bb59103157d2))
* **api:** api update ([#153](https://github.com/lastmile-ai/lastmile-python/issues/153)) ([ee100d0](https://github.com/lastmile-ai/lastmile-python/commit/ee100d0a0d3c413a2987d1650521d4a978b4b8ce))
* Fix: fix bad metadata field ([2614632](https://github.com/lastmile-ai/lastmile-python/commit/261463219de2a2914ddf473ee09694315960a7f6))


### Chores

* **internal:** bummp ruff dependency ([#155](https://github.com/lastmile-ai/lastmile-python/issues/155)) ([ca07a1e](https://github.com/lastmile-ai/lastmile-python/commit/ca07a1ea4685d7653e1593280391a35fe3992bb4))
* **internal:** change default timeout to an int ([#154](https://github.com/lastmile-ai/lastmile-python/issues/154)) ([68d8b60](https://github.com/lastmile-ai/lastmile-python/commit/68d8b60ccbad0a8f28b7b3016255cff713bc0b72))
* **internal:** minor formatting changes ([#144](https://github.com/lastmile-ai/lastmile-python/issues/144)) ([f83d2ff](https://github.com/lastmile-ai/lastmile-python/commit/f83d2ff3469dafeebfbfca7c0a7baea6ffa0e354))

## 0.6.0 (2025-01-23)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([#135](https://github.com/lastmile-ai/lastmile-python/issues/135)) ([cccd599](https://github.com/lastmile-ai/lastmile-python/commit/cccd599e25dca78e09094435998b9d9ac4fad56d))

## 0.5.0 (2025-01-23)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.4.0...v0.5.0)

### Features

* **api:** api update ([#121](https://github.com/lastmile-ai/lastmile-python/issues/121)) ([0846ba3](https://github.com/lastmile-ai/lastmile-python/commit/0846ba315a43b39c75b1aced50621110d365f0a1))
* **api:** api update ([#123](https://github.com/lastmile-ai/lastmile-python/issues/123)) ([9f35a25](https://github.com/lastmile-ai/lastmile-python/commit/9f35a254b242fef7a37b81bb0070a7177bf62d69))


### Bug Fixes

* **client:** only call .close() when needed ([#111](https://github.com/lastmile-ai/lastmile-python/issues/111)) ([1e80c55](https://github.com/lastmile-ai/lastmile-python/commit/1e80c553f39e95da6752ab5109c0cf1de5bcf3a2))
* correctly handle deserialising `cls` fields ([#114](https://github.com/lastmile-ai/lastmile-python/issues/114)) ([51ac463](https://github.com/lastmile-ai/lastmile-python/commit/51ac4635aafa838f6ded6c1d085b4272d3ab8874))


### Chores

* **internal:** bump httpx dependency ([#109](https://github.com/lastmile-ai/lastmile-python/issues/109)) ([6c73891](https://github.com/lastmile-ai/lastmile-python/commit/6c73891a86fcb15f96ce974230281e34077d22d6))
* **internal:** codegen related update ([#113](https://github.com/lastmile-ai/lastmile-python/issues/113)) ([c132d6a](https://github.com/lastmile-ai/lastmile-python/commit/c132d6a5e7d6f632bf4268cfd83b51f842f1789a))
* **internal:** codegen related update ([#125](https://github.com/lastmile-ai/lastmile-python/issues/125)) ([afe2a7b](https://github.com/lastmile-ai/lastmile-python/commit/afe2a7b9c36dc469ff8efdf36ca2aecd334dac77))
* **internal:** codegen related update ([#132](https://github.com/lastmile-ai/lastmile-python/issues/132)) ([95745fe](https://github.com/lastmile-ai/lastmile-python/commit/95745fe467e33a705f92a1de6812b4d707577340))
* **internal:** codegen related update ([#133](https://github.com/lastmile-ai/lastmile-python/issues/133)) ([6f3b33b](https://github.com/lastmile-ai/lastmile-python/commit/6f3b33bf7d0cd7407ee5e05bec5e78eb1acbc804))


### Documentation

* fix typos ([#112](https://github.com/lastmile-ai/lastmile-python/issues/112)) ([7d23b1d](https://github.com/lastmile-ai/lastmile-python/commit/7d23b1db786b4cd5f2e21012628a27d0bac73f04))

## 0.4.0 (2025-01-07)

Full Changelog: [v0.3.4...v0.4.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.3.4...v0.4.0)

### Features

* Fix for Label Api ([8b56e2c](https://github.com/lastmile-ai/lastmile-python/commit/8b56e2c6c52250fb8ca865be7800acb18b82d792))


### Chores

* add missing isclass check ([#103](https://github.com/lastmile-ai/lastmile-python/issues/103)) ([c44b1d0](https://github.com/lastmile-ai/lastmile-python/commit/c44b1d0cd3e5f5c33ef8406272d8ef882cdd10b5))
* **internal:** add support for TypeAliasType ([#94](https://github.com/lastmile-ai/lastmile-python/issues/94)) ([1c27f8a](https://github.com/lastmile-ai/lastmile-python/commit/1c27f8adde0240dd8d7ef74dcbb9fa83d31221d9))
* **internal:** bump pyright ([#93](https://github.com/lastmile-ai/lastmile-python/issues/93)) ([41ea4a0](https://github.com/lastmile-ai/lastmile-python/commit/41ea4a0a1b9f28081cac3ca8ff1ac8a3c7e6d90b))
* **internal:** codegen related update ([#102](https://github.com/lastmile-ai/lastmile-python/issues/102)) ([e5e8f3f](https://github.com/lastmile-ai/lastmile-python/commit/e5e8f3f3106249bd4afd1ae370a1643edb89c08d))
* **internal:** codegen related update ([#91](https://github.com/lastmile-ai/lastmile-python/issues/91)) ([0d00b4a](https://github.com/lastmile-ai/lastmile-python/commit/0d00b4a8ea52826963570d5c9d7a81a40fac2fb3))
* **internal:** codegen related update ([#95](https://github.com/lastmile-ai/lastmile-python/issues/95)) ([47faa2d](https://github.com/lastmile-ai/lastmile-python/commit/47faa2da716f29e2c8592f41768429e1dabcb5dd))
* **internal:** codegen related update ([#96](https://github.com/lastmile-ai/lastmile-python/issues/96)) ([10e30d2](https://github.com/lastmile-ai/lastmile-python/commit/10e30d244a717f0335b679b46b86516a81f35f88))
* **internal:** fix some typos ([#99](https://github.com/lastmile-ai/lastmile-python/issues/99)) ([4c5cb67](https://github.com/lastmile-ai/lastmile-python/commit/4c5cb67d35a80b08ca1199a39ca9ffaea744b2b9))
* **internal:** updated imports ([#97](https://github.com/lastmile-ai/lastmile-python/issues/97)) ([82fdca6](https://github.com/lastmile-ai/lastmile-python/commit/82fdca6cace16be738e153c6d338bbd6e1498bde))
* **internal:** version bump ([#105](https://github.com/lastmile-ai/lastmile-python/issues/105)) ([f989444](https://github.com/lastmile-ai/lastmile-python/commit/f989444629cd6e4e1878cddecf4df9c33b085865))


### Documentation

* **readme:** example snippet for client context manager ([#98](https://github.com/lastmile-ai/lastmile-python/issues/98)) ([951d809](https://github.com/lastmile-ai/lastmile-python/commit/951d80932708e8cf610dafbb2576aba63a12495c))
* **readme:** fix http client proxies example ([#92](https://github.com/lastmile-ai/lastmile-python/issues/92)) ([3037642](https://github.com/lastmile-ai/lastmile-python/commit/3037642e104092a1d947e6efa03c7f6bf0004aff))

## 0.3.4 (2024-12-18)

Full Changelog: [v0.3.3...v0.3.4](https://github.com/lastmile-ai/lastmile-python/compare/v0.3.3...v0.3.4)

### Chores

* **internal:** codegen related update ([#88](https://github.com/lastmile-ai/lastmile-python/issues/88)) ([6ad25e1](https://github.com/lastmile-ai/lastmile-python/commit/6ad25e19a39c402bf371cac28c76b1bd16b95adf))
* make the `Omit` type public ([#90](https://github.com/lastmile-ai/lastmile-python/issues/90)) ([8204894](https://github.com/lastmile-ai/lastmile-python/commit/82048940b5519083c42c7772600ba7e9f2c1b697))

## 0.3.3 (2024-11-28)

Full Changelog: [v0.3.2...v0.3.3](https://github.com/lastmile-ai/lastmile-python/compare/v0.3.2...v0.3.3)

### Bug Fixes

* **client:** compat with new httpx 0.28.0 release ([#86](https://github.com/lastmile-ai/lastmile-python/issues/86)) ([c38783f](https://github.com/lastmile-ai/lastmile-python/commit/c38783f315634feb2b783cee7b0b017f5fe9d801))


### Chores

* **internal:** codegen related update ([#84](https://github.com/lastmile-ai/lastmile-python/issues/84)) ([2947573](https://github.com/lastmile-ai/lastmile-python/commit/2947573b61c490ffd550464eee2a4c9eaaae0940))

## 0.3.2 (2024-11-26)

Full Changelog: [v0.3.1...v0.3.2](https://github.com/lastmile-ai/lastmile-python/compare/v0.3.1...v0.3.2)

### Chores

* **internal:** fix compat model_dump method when warnings are passed ([#78](https://github.com/lastmile-ai/lastmile-python/issues/78)) ([abb0a58](https://github.com/lastmile-ai/lastmile-python/commit/abb0a58b4fbdccd3e8fa3fb0d9c5bbc0d410c085))
* remove now unused `cached-property` dep ([#81](https://github.com/lastmile-ai/lastmile-python/issues/81)) ([4c1a40a](https://github.com/lastmile-ai/lastmile-python/commit/4c1a40ac0da337f1976abcb5b18448c30aba02ab))


### Documentation

* add info log level to readme ([#80](https://github.com/lastmile-ai/lastmile-python/issues/80)) ([48683a3](https://github.com/lastmile-ai/lastmile-python/commit/48683a30c9c7cfefeb854e61ab4df23e7890dd08))

## 0.3.1 (2024-11-18)

Full Changelog: [v0.2.7...v0.3.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.7...v0.3.1)

### Chores

* rebuild project due to codegen change ([#73](https://github.com/lastmile-ai/lastmile-python/issues/73)) ([c99a242](https://github.com/lastmile-ai/lastmile-python/commit/c99a24250f0cc8171de0a9a1be293b07a661da44))
* rebuild project due to codegen change ([#75](https://github.com/lastmile-ai/lastmile-python/issues/75)) ([ecfecef](https://github.com/lastmile-ai/lastmile-python/commit/ecfecef3d8341b397a38a3db0d9151b3231ce652))
* rebuild project due to codegen change ([#76](https://github.com/lastmile-ai/lastmile-python/issues/76)) ([6463aaf](https://github.com/lastmile-ai/lastmile-python/commit/6463aaf36f3ab3e3f180a00b0d523a300eb531f1))

## 0.2.7 (2024-11-14)

Full Changelog: [v0.3.0...v0.2.7](https://github.com/lastmile-ai/lastmile-python/compare/v0.3.0...v0.2.7)

### Features

* **api:** api update ([#12](https://github.com/lastmile-ai/lastmile-python/issues/12)) ([1cd0e25](https://github.com/lastmile-ai/lastmile-python/commit/1cd0e25bfe9098ae616f304f5fc4bbfe7b07ac9d))
* **api:** api update ([#13](https://github.com/lastmile-ai/lastmile-python/issues/13)) ([3c13518](https://github.com/lastmile-ai/lastmile-python/commit/3c13518ea1579bc493ad4a115609884165b4d722))
* **api:** api update ([#14](https://github.com/lastmile-ai/lastmile-python/issues/14)) ([b0bd047](https://github.com/lastmile-ai/lastmile-python/commit/b0bd047fe47fff2684aa0c5cb828bfe3ed4c2bee))
* **api:** api update ([#15](https://github.com/lastmile-ai/lastmile-python/issues/15)) ([c7a9bac](https://github.com/lastmile-ai/lastmile-python/commit/c7a9bac766b7c64cc3fafcc48b5340c835ed7cee))
* **api:** api update ([#16](https://github.com/lastmile-ai/lastmile-python/issues/16)) ([76d365f](https://github.com/lastmile-ai/lastmile-python/commit/76d365f6fa238843f1bc07d47f957048ffbbf5bf))
* **api:** api update ([#17](https://github.com/lastmile-ai/lastmile-python/issues/17)) ([56248d2](https://github.com/lastmile-ai/lastmile-python/commit/56248d2dd1924a98c97c1fbfec442e314851b3f9))
* **api:** api update ([#18](https://github.com/lastmile-ai/lastmile-python/issues/18)) ([e8ef17f](https://github.com/lastmile-ai/lastmile-python/commit/e8ef17f4d8e28647ab939adcc182da7b5e582729))
* **api:** api update ([#19](https://github.com/lastmile-ai/lastmile-python/issues/19)) ([b7ead43](https://github.com/lastmile-ai/lastmile-python/commit/b7ead435ef06cb7bc2257fc0071cd22a2ad41993))
* **api:** api update ([#20](https://github.com/lastmile-ai/lastmile-python/issues/20)) ([5592162](https://github.com/lastmile-ai/lastmile-python/commit/55921626bec2884ca5b6592d0cc2896bb5df5f32))
* **api:** api update ([#21](https://github.com/lastmile-ai/lastmile-python/issues/21)) ([125603c](https://github.com/lastmile-ai/lastmile-python/commit/125603caf869b557319cdaea095769823bc61621))
* **api:** api update ([#22](https://github.com/lastmile-ai/lastmile-python/issues/22)) ([7b60dd1](https://github.com/lastmile-ai/lastmile-python/commit/7b60dd1a4e28d6e7feaa88c0fac5f3a1be8d87fb))
* **api:** api update ([#23](https://github.com/lastmile-ai/lastmile-python/issues/23)) ([dfee299](https://github.com/lastmile-ai/lastmile-python/commit/dfee299be547de0e555e31c42791dd330d03be09))
* **api:** api update ([#24](https://github.com/lastmile-ai/lastmile-python/issues/24)) ([e61976a](https://github.com/lastmile-ai/lastmile-python/commit/e61976a75aaee2c89a5d8eb1da8bddb99919e567))
* **api:** api update ([#25](https://github.com/lastmile-ai/lastmile-python/issues/25)) ([d4dafd3](https://github.com/lastmile-ai/lastmile-python/commit/d4dafd327528f2f776eb82866b0fc2477a41dd52))
* **api:** api update ([#26](https://github.com/lastmile-ai/lastmile-python/issues/26)) ([dbfd411](https://github.com/lastmile-ai/lastmile-python/commit/dbfd411b51874a74ba72dcf76e31cc9a2c298ac8))
* **api:** api update ([#27](https://github.com/lastmile-ai/lastmile-python/issues/27)) ([00e8497](https://github.com/lastmile-ai/lastmile-python/commit/00e8497d87eeed272faa0d89914016bf7e823d63))
* **api:** api update ([#28](https://github.com/lastmile-ai/lastmile-python/issues/28)) ([912f2f7](https://github.com/lastmile-ai/lastmile-python/commit/912f2f775bbc38b218b74f6fb5e0df9fa162c46a))
* **api:** api update ([#34](https://github.com/lastmile-ai/lastmile-python/issues/34)) ([faffea3](https://github.com/lastmile-ai/lastmile-python/commit/faffea36aa070cf96c2d8ce9aee4e61a5c855bda))
* **api:** api update ([#35](https://github.com/lastmile-ai/lastmile-python/issues/35)) ([4077539](https://github.com/lastmile-ai/lastmile-python/commit/407753915a83c09dfb202ebd1dfcaf988cb62671))
* **api:** api update ([#36](https://github.com/lastmile-ai/lastmile-python/issues/36)) ([8c07793](https://github.com/lastmile-ai/lastmile-python/commit/8c0779359b621804a16a8d7f2b3f6440e699261e))
* **api:** api update ([#38](https://github.com/lastmile-ai/lastmile-python/issues/38)) ([4599222](https://github.com/lastmile-ai/lastmile-python/commit/459922286d7913483d35570de368275f23963b5c))
* **api:** api update ([#39](https://github.com/lastmile-ai/lastmile-python/issues/39)) ([6ab3cc4](https://github.com/lastmile-ai/lastmile-python/commit/6ab3cc48ae8149da333a6648ef899ca228653cfe))
* **api:** api update ([#41](https://github.com/lastmile-ai/lastmile-python/issues/41)) ([64f7ea0](https://github.com/lastmile-ai/lastmile-python/commit/64f7ea0b345cc0e7da0a005b8efea99e4c03251c))
* **api:** api update ([#42](https://github.com/lastmile-ai/lastmile-python/issues/42)) ([1c37dda](https://github.com/lastmile-ai/lastmile-python/commit/1c37dda7d7e6a1840f1b231b7a714875b708e5a3))
* **api:** api update ([#43](https://github.com/lastmile-ai/lastmile-python/issues/43)) ([489b2b3](https://github.com/lastmile-ai/lastmile-python/commit/489b2b37b346dbda8e4a5b6ec857742c86ee950d))
* **api:** api update ([#44](https://github.com/lastmile-ai/lastmile-python/issues/44)) ([6968875](https://github.com/lastmile-ai/lastmile-python/commit/6968875d01cccbdde81d62000af2b6f5ad7fd9e1))
* **api:** api update ([#45](https://github.com/lastmile-ai/lastmile-python/issues/45)) ([a7404a6](https://github.com/lastmile-ai/lastmile-python/commit/a7404a6be5d476b47c301d73eee47a5477c70829))
* **api:** manual updates ([bef66b6](https://github.com/lastmile-ai/lastmile-python/commit/bef66b6d9b34c9bbdc682083670b7e72e26e63b3))
* **api:** manual updates ([71c6860](https://github.com/lastmile-ai/lastmile-python/commit/71c68603c7b6ee45798881cd74a255434c4600f5))
* **api:** manual updates ([a4976c3](https://github.com/lastmile-ai/lastmile-python/commit/a4976c3c4265c168347989a6776cb731bd788ec4))
* **api:** manual updates ([7d33740](https://github.com/lastmile-ai/lastmile-python/commit/7d3374067a08e0b2fb6f0c981b83a1924b9c5959))
* **api:** manual updates ([459013a](https://github.com/lastmile-ai/lastmile-python/commit/459013afded932da2ea506a5858f1ad2f5395ff1))
* **api:** manual updates ([ba9baeb](https://github.com/lastmile-ai/lastmile-python/commit/ba9baebe6cecacbc4a1da569b5a8141de5dd86b7))
* **api:** manual updates ([30b1d82](https://github.com/lastmile-ai/lastmile-python/commit/30b1d825b95a35f730affa9dce915e2e9607b502))
* **api:** manual updates ([353997c](https://github.com/lastmile-ai/lastmile-python/commit/353997c164e7bb24e6d04cbe745365b4a59a2e17))
* **api:** manual updates ([d41db01](https://github.com/lastmile-ai/lastmile-python/commit/d41db0146761bfea263c6a888f1efec8264d180a))
* **api:** manual updates ([c8587b0](https://github.com/lastmile-ai/lastmile-python/commit/c8587b04c6f86791103dcccf042176752fe2ddc1))
* **api:** manual updates ([#31](https://github.com/lastmile-ai/lastmile-python/issues/31)) ([94a653d](https://github.com/lastmile-ai/lastmile-python/commit/94a653ddf5aad00d776c7396d02cf8ef74a895fd))
* **api:** manual updates ([#33](https://github.com/lastmile-ai/lastmile-python/issues/33)) ([81ad3b9](https://github.com/lastmile-ai/lastmile-python/commit/81ad3b91ba9b4de495dbda38075e53589cf0f35c))
* **api:** manual updates ([#37](https://github.com/lastmile-ai/lastmile-python/issues/37)) ([bfefa24](https://github.com/lastmile-ai/lastmile-python/commit/bfefa2469b3e922edb96e3d2e978d7f4ececcf73))
* **api:** manual updates ([#4](https://github.com/lastmile-ai/lastmile-python/issues/4)) ([cac7caf](https://github.com/lastmile-ai/lastmile-python/commit/cac7caf774f9f35a14632ed5a26fa295b52fbdd8))
* **api:** manual updates ([#40](https://github.com/lastmile-ai/lastmile-python/issues/40)) ([0285b9d](https://github.com/lastmile-ai/lastmile-python/commit/0285b9d5d214485fdd7aab21437e88b777207146))
* **api:** manual updates ([#46](https://github.com/lastmile-ai/lastmile-python/issues/46)) ([d2ffd39](https://github.com/lastmile-ai/lastmile-python/commit/d2ffd39493218abfd84505b27f36fb4528b216c1))
* **api:** manual updates ([#5](https://github.com/lastmile-ai/lastmile-python/issues/5)) ([eb3ec90](https://github.com/lastmile-ai/lastmile-python/commit/eb3ec90416dcac5299db02d4cd89a5c01742da3d))
* **api:** manual updates ([#53](https://github.com/lastmile-ai/lastmile-python/issues/53)) ([df3c8bd](https://github.com/lastmile-ai/lastmile-python/commit/df3c8bd97623819c59942df7dee01510d5a12a05))
* **api:** manual updates ([#56](https://github.com/lastmile-ai/lastmile-python/issues/56)) ([3c0537a](https://github.com/lastmile-ai/lastmile-python/commit/3c0537a0873a3c6e51115a54ad75468cabc31978))
* **api:** manual updates ([#70](https://github.com/lastmile-ai/lastmile-python/issues/70)) ([40d03ea](https://github.com/lastmile-ai/lastmile-python/commit/40d03ea5da84bf7976e1ab38acf8d85d1b8eb7e2))
* **api:** OpenAPI spec update via Stainless API ([#10](https://github.com/lastmile-ai/lastmile-python/issues/10)) ([afd69a7](https://github.com/lastmile-ai/lastmile-python/commit/afd69a78c04af9da0508b532f41ce59aac82b5c7))
* **api:** OpenAPI spec update via Stainless API ([#11](https://github.com/lastmile-ai/lastmile-python/issues/11)) ([2ce2481](https://github.com/lastmile-ai/lastmile-python/commit/2ce2481d1c2ce7741dee639b5d9b13a48736676f))
* **api:** OpenAPI spec update via Stainless API ([#8](https://github.com/lastmile-ai/lastmile-python/issues/8)) ([8f9bb2d](https://github.com/lastmile-ai/lastmile-python/commit/8f9bb2dd5ddabfe1d5945d42757bbcefa6c54d88))
* auto_eval ([915aace](https://github.com/lastmile-ai/lastmile-python/commit/915aace1c2a0b986555578c83b91d7bd5aae7973))
* fixup ([503b3c6](https://github.com/lastmile-ai/lastmile-python/commit/503b3c672de06436d5486503f6d908c8723adfeb))
* nov_12_230 ([817ce2c](https://github.com/lastmile-ai/lastmile-python/commit/817ce2c4c035613cc50129b0af6c2ad4db433462))
* typefix ([3aca04c](https://github.com/lastmile-ai/lastmile-python/commit/3aca04c8784a4d5502ee13363de121b2aea8aa24))


### Bug Fixes

* **client:** avoid OverflowError with very large retry counts ([#4](https://github.com/lastmile-ai/lastmile-python/issues/4)) ([47d0fb2](https://github.com/lastmile-ai/lastmile-python/commit/47d0fb29f89f32d6fe59ee16228ea934bd502216))


### Chores

* add repr to PageInfo class ([8d0dde1](https://github.com/lastmile-ai/lastmile-python/commit/8d0dde1480e1eff8a43c89b10ce9399789787411))
* go live ([#1](https://github.com/lastmile-ai/lastmile-python/issues/1)) ([d1a9313](https://github.com/lastmile-ai/lastmile-python/commit/d1a9313a1041302aa553a751b2db3a1777721e9a))
* go live ([#1](https://github.com/lastmile-ai/lastmile-python/issues/1)) ([9e6fc92](https://github.com/lastmile-ai/lastmile-python/commit/9e6fc92ebec5b9e78b2c18938d50583d825a0188))
* **internal:** version bump ([#51](https://github.com/lastmile-ai/lastmile-python/issues/51)) ([5259f11](https://github.com/lastmile-ai/lastmile-python/commit/5259f11dac328eaf2cb24413b5cb4964a77388d9))
* rebuild project due to codegen change ([#47](https://github.com/lastmile-ai/lastmile-python/issues/47)) ([4eacace](https://github.com/lastmile-ai/lastmile-python/commit/4eacaced23cc75ebb13e93d6fa0292728239f4a8))
* rebuild project due to codegen change ([#54](https://github.com/lastmile-ai/lastmile-python/issues/54)) ([9b519c2](https://github.com/lastmile-ai/lastmile-python/commit/9b519c2dc4b54dbc248e5178fc3635572c4f8f6c))
* rebuild project due to codegen change ([#55](https://github.com/lastmile-ai/lastmile-python/issues/55)) ([aa98694](https://github.com/lastmile-ai/lastmile-python/commit/aa98694e29961df298030996f863c0a89d230588))
* rebuild project due to codegen change ([#61](https://github.com/lastmile-ai/lastmile-python/issues/61)) ([c5c7275](https://github.com/lastmile-ai/lastmile-python/commit/c5c72757dc38bd7b68768fd797f3d1d6eb5d6f89))
* rebuild project due to codegen change ([#62](https://github.com/lastmile-ai/lastmile-python/issues/62)) ([4bbee07](https://github.com/lastmile-ai/lastmile-python/commit/4bbee07ec36cd1ae97489d59fca1edf2b35a2ed2))
* update SDK settings ([2eba47f](https://github.com/lastmile-ai/lastmile-python/commit/2eba47ffaf5a53c54ec945a60cfa3f08e47812a0))
* update SDK settings ([#3](https://github.com/lastmile-ai/lastmile-python/issues/3)) ([1d43bb0](https://github.com/lastmile-ai/lastmile-python/commit/1d43bb0bda7d80b970b051425be1ab4a844a246f))
* update SDK settings ([#3](https://github.com/lastmile-ai/lastmile-python/issues/3)) ([e63c99b](https://github.com/lastmile-ai/lastmile-python/commit/e63c99b3a52e8eb5dc90900f91c32d65b1a747f5))

## 0.3.0 (2024-11-13)

Full Changelog: [v0.2.5...v0.3.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.5...v0.3.0)

### Features

* typefix ([758644b](https://github.com/lastmile-ai/lastmile-python/commit/758644be84c7479b228256136150c739f9d2f0bd))

## 0.2.5 (2024-11-12)

Full Changelog: [v0.2.4...v0.2.5](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.4...v0.2.5)

### Chores

* rebuild project due to codegen change ([#61](https://github.com/lastmile-ai/lastmile-python/issues/61)) ([c5c7275](https://github.com/lastmile-ai/lastmile-python/commit/c5c72757dc38bd7b68768fd797f3d1d6eb5d6f89))

## 0.2.4 (2024-11-12)

Full Changelog: [v0.2.3...v0.2.4](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.3...v0.2.4)

### Features

* **api:** manual updates ([#53](https://github.com/lastmile-ai/lastmile-python/issues/53)) ([df3c8bd](https://github.com/lastmile-ai/lastmile-python/commit/df3c8bd97623819c59942df7dee01510d5a12a05))
* **api:** manual updates ([#56](https://github.com/lastmile-ai/lastmile-python/issues/56)) ([3c0537a](https://github.com/lastmile-ai/lastmile-python/commit/3c0537a0873a3c6e51115a54ad75468cabc31978))
* nov_12_230 ([817ce2c](https://github.com/lastmile-ai/lastmile-python/commit/817ce2c4c035613cc50129b0af6c2ad4db433462))


### Chores

* **internal:** version bump ([#51](https://github.com/lastmile-ai/lastmile-python/issues/51)) ([5259f11](https://github.com/lastmile-ai/lastmile-python/commit/5259f11dac328eaf2cb24413b5cb4964a77388d9))
* rebuild project due to codegen change ([#54](https://github.com/lastmile-ai/lastmile-python/issues/54)) ([9b519c2](https://github.com/lastmile-ai/lastmile-python/commit/9b519c2dc4b54dbc248e5178fc3635572c4f8f6c))
* rebuild project due to codegen change ([#55](https://github.com/lastmile-ai/lastmile-python/issues/55)) ([aa98694](https://github.com/lastmile-ai/lastmile-python/commit/aa98694e29961df298030996f863c0a89d230588))

## 0.2.3 (2024-11-11)

Full Changelog: [v0.2.2...v0.2.3](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.2...v0.2.3)

### Features

* auto_eval ([915aace](https://github.com/lastmile-ai/lastmile-python/commit/915aace1c2a0b986555578c83b91d7bd5aae7973))
* fixup ([503b3c6](https://github.com/lastmile-ai/lastmile-python/commit/503b3c672de06436d5486503f6d908c8723adfeb))

## 0.2.2 (2024-11-11)

Full Changelog: [v0.2.1...v0.2.2](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.1...v0.2.2)

### Features

* **api:** api update ([#34](https://github.com/lastmile-ai/lastmile-python/issues/34)) ([faffea3](https://github.com/lastmile-ai/lastmile-python/commit/faffea36aa070cf96c2d8ce9aee4e61a5c855bda))
* **api:** api update ([#35](https://github.com/lastmile-ai/lastmile-python/issues/35)) ([4077539](https://github.com/lastmile-ai/lastmile-python/commit/407753915a83c09dfb202ebd1dfcaf988cb62671))
* **api:** api update ([#36](https://github.com/lastmile-ai/lastmile-python/issues/36)) ([8c07793](https://github.com/lastmile-ai/lastmile-python/commit/8c0779359b621804a16a8d7f2b3f6440e699261e))
* **api:** api update ([#38](https://github.com/lastmile-ai/lastmile-python/issues/38)) ([4599222](https://github.com/lastmile-ai/lastmile-python/commit/459922286d7913483d35570de368275f23963b5c))
* **api:** api update ([#39](https://github.com/lastmile-ai/lastmile-python/issues/39)) ([6ab3cc4](https://github.com/lastmile-ai/lastmile-python/commit/6ab3cc48ae8149da333a6648ef899ca228653cfe))
* **api:** api update ([#41](https://github.com/lastmile-ai/lastmile-python/issues/41)) ([64f7ea0](https://github.com/lastmile-ai/lastmile-python/commit/64f7ea0b345cc0e7da0a005b8efea99e4c03251c))
* **api:** api update ([#42](https://github.com/lastmile-ai/lastmile-python/issues/42)) ([1c37dda](https://github.com/lastmile-ai/lastmile-python/commit/1c37dda7d7e6a1840f1b231b7a714875b708e5a3))
* **api:** api update ([#43](https://github.com/lastmile-ai/lastmile-python/issues/43)) ([489b2b3](https://github.com/lastmile-ai/lastmile-python/commit/489b2b37b346dbda8e4a5b6ec857742c86ee950d))
* **api:** api update ([#44](https://github.com/lastmile-ai/lastmile-python/issues/44)) ([6968875](https://github.com/lastmile-ai/lastmile-python/commit/6968875d01cccbdde81d62000af2b6f5ad7fd9e1))
* **api:** api update ([#45](https://github.com/lastmile-ai/lastmile-python/issues/45)) ([a7404a6](https://github.com/lastmile-ai/lastmile-python/commit/a7404a6be5d476b47c301d73eee47a5477c70829))
* **api:** manual updates ([#31](https://github.com/lastmile-ai/lastmile-python/issues/31)) ([94a653d](https://github.com/lastmile-ai/lastmile-python/commit/94a653ddf5aad00d776c7396d02cf8ef74a895fd))
* **api:** manual updates ([#33](https://github.com/lastmile-ai/lastmile-python/issues/33)) ([81ad3b9](https://github.com/lastmile-ai/lastmile-python/commit/81ad3b91ba9b4de495dbda38075e53589cf0f35c))
* **api:** manual updates ([#37](https://github.com/lastmile-ai/lastmile-python/issues/37)) ([bfefa24](https://github.com/lastmile-ai/lastmile-python/commit/bfefa2469b3e922edb96e3d2e978d7f4ececcf73))
* **api:** manual updates ([#40](https://github.com/lastmile-ai/lastmile-python/issues/40)) ([0285b9d](https://github.com/lastmile-ai/lastmile-python/commit/0285b9d5d214485fdd7aab21437e88b777207146))
* **api:** manual updates ([#46](https://github.com/lastmile-ai/lastmile-python/issues/46)) ([d2ffd39](https://github.com/lastmile-ai/lastmile-python/commit/d2ffd39493218abfd84505b27f36fb4528b216c1))


### Chores

* rebuild project due to codegen change ([#47](https://github.com/lastmile-ai/lastmile-python/issues/47)) ([4eacace](https://github.com/lastmile-ai/lastmile-python/commit/4eacaced23cc75ebb13e93d6fa0292728239f4a8))

## 0.2.1 (2024-10-21)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/lastmile-ai/lastmile-python/compare/v0.2.0...v0.2.1)

### Features

* **api:** api update ([#12](https://github.com/lastmile-ai/lastmile-python/issues/12)) ([1cd0e25](https://github.com/lastmile-ai/lastmile-python/commit/1cd0e25bfe9098ae616f304f5fc4bbfe7b07ac9d))
* **api:** api update ([#13](https://github.com/lastmile-ai/lastmile-python/issues/13)) ([3c13518](https://github.com/lastmile-ai/lastmile-python/commit/3c13518ea1579bc493ad4a115609884165b4d722))
* **api:** api update ([#14](https://github.com/lastmile-ai/lastmile-python/issues/14)) ([b0bd047](https://github.com/lastmile-ai/lastmile-python/commit/b0bd047fe47fff2684aa0c5cb828bfe3ed4c2bee))
* **api:** api update ([#15](https://github.com/lastmile-ai/lastmile-python/issues/15)) ([c7a9bac](https://github.com/lastmile-ai/lastmile-python/commit/c7a9bac766b7c64cc3fafcc48b5340c835ed7cee))
* **api:** api update ([#16](https://github.com/lastmile-ai/lastmile-python/issues/16)) ([76d365f](https://github.com/lastmile-ai/lastmile-python/commit/76d365f6fa238843f1bc07d47f957048ffbbf5bf))
* **api:** api update ([#17](https://github.com/lastmile-ai/lastmile-python/issues/17)) ([56248d2](https://github.com/lastmile-ai/lastmile-python/commit/56248d2dd1924a98c97c1fbfec442e314851b3f9))
* **api:** api update ([#18](https://github.com/lastmile-ai/lastmile-python/issues/18)) ([e8ef17f](https://github.com/lastmile-ai/lastmile-python/commit/e8ef17f4d8e28647ab939adcc182da7b5e582729))
* **api:** api update ([#19](https://github.com/lastmile-ai/lastmile-python/issues/19)) ([b7ead43](https://github.com/lastmile-ai/lastmile-python/commit/b7ead435ef06cb7bc2257fc0071cd22a2ad41993))
* **api:** api update ([#20](https://github.com/lastmile-ai/lastmile-python/issues/20)) ([5592162](https://github.com/lastmile-ai/lastmile-python/commit/55921626bec2884ca5b6592d0cc2896bb5df5f32))
* **api:** api update ([#21](https://github.com/lastmile-ai/lastmile-python/issues/21)) ([125603c](https://github.com/lastmile-ai/lastmile-python/commit/125603caf869b557319cdaea095769823bc61621))
* **api:** api update ([#22](https://github.com/lastmile-ai/lastmile-python/issues/22)) ([7b60dd1](https://github.com/lastmile-ai/lastmile-python/commit/7b60dd1a4e28d6e7feaa88c0fac5f3a1be8d87fb))
* **api:** api update ([#23](https://github.com/lastmile-ai/lastmile-python/issues/23)) ([dfee299](https://github.com/lastmile-ai/lastmile-python/commit/dfee299be547de0e555e31c42791dd330d03be09))
* **api:** api update ([#24](https://github.com/lastmile-ai/lastmile-python/issues/24)) ([e61976a](https://github.com/lastmile-ai/lastmile-python/commit/e61976a75aaee2c89a5d8eb1da8bddb99919e567))
* **api:** api update ([#25](https://github.com/lastmile-ai/lastmile-python/issues/25)) ([d4dafd3](https://github.com/lastmile-ai/lastmile-python/commit/d4dafd327528f2f776eb82866b0fc2477a41dd52))
* **api:** api update ([#26](https://github.com/lastmile-ai/lastmile-python/issues/26)) ([dbfd411](https://github.com/lastmile-ai/lastmile-python/commit/dbfd411b51874a74ba72dcf76e31cc9a2c298ac8))
* **api:** api update ([#27](https://github.com/lastmile-ai/lastmile-python/issues/27)) ([00e8497](https://github.com/lastmile-ai/lastmile-python/commit/00e8497d87eeed272faa0d89914016bf7e823d63))
* **api:** api update ([#28](https://github.com/lastmile-ai/lastmile-python/issues/28)) ([912f2f7](https://github.com/lastmile-ai/lastmile-python/commit/912f2f775bbc38b218b74f6fb5e0df9fa162c46a))
* **api:** OpenAPI spec update via Stainless API ([#10](https://github.com/lastmile-ai/lastmile-python/issues/10)) ([afd69a7](https://github.com/lastmile-ai/lastmile-python/commit/afd69a78c04af9da0508b532f41ce59aac82b5c7))
* **api:** OpenAPI spec update via Stainless API ([#11](https://github.com/lastmile-ai/lastmile-python/issues/11)) ([2ce2481](https://github.com/lastmile-ai/lastmile-python/commit/2ce2481d1c2ce7741dee639b5d9b13a48736676f))
* **api:** OpenAPI spec update via Stainless API ([#8](https://github.com/lastmile-ai/lastmile-python/issues/8)) ([8f9bb2d](https://github.com/lastmile-ai/lastmile-python/commit/8f9bb2dd5ddabfe1d5945d42757bbcefa6c54d88))

## 0.2.0 (2024-10-07)

Full Changelog: [v0.0.1-alpha.0...v0.2.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.0.1-alpha.0...v0.2.0)

### Features

* **api:** manual updates ([bef66b6](https://github.com/lastmile-ai/lastmile-python/commit/bef66b6d9b34c9bbdc682083670b7e72e26e63b3))
* **api:** manual updates ([71c6860](https://github.com/lastmile-ai/lastmile-python/commit/71c68603c7b6ee45798881cd74a255434c4600f5))
* **api:** manual updates ([a4976c3](https://github.com/lastmile-ai/lastmile-python/commit/a4976c3c4265c168347989a6776cb731bd788ec4))
* **api:** manual updates ([7d33740](https://github.com/lastmile-ai/lastmile-python/commit/7d3374067a08e0b2fb6f0c981b83a1924b9c5959))
* **api:** manual updates ([459013a](https://github.com/lastmile-ai/lastmile-python/commit/459013afded932da2ea506a5858f1ad2f5395ff1))
* **api:** manual updates ([ba9baeb](https://github.com/lastmile-ai/lastmile-python/commit/ba9baebe6cecacbc4a1da569b5a8141de5dd86b7))
* **api:** manual updates ([30b1d82](https://github.com/lastmile-ai/lastmile-python/commit/30b1d825b95a35f730affa9dce915e2e9607b502))
* **api:** manual updates ([353997c](https://github.com/lastmile-ai/lastmile-python/commit/353997c164e7bb24e6d04cbe745365b4a59a2e17))
* **api:** manual updates ([d41db01](https://github.com/lastmile-ai/lastmile-python/commit/d41db0146761bfea263c6a888f1efec8264d180a))
* **api:** manual updates ([c8587b0](https://github.com/lastmile-ai/lastmile-python/commit/c8587b04c6f86791103dcccf042176752fe2ddc1))
* **api:** manual updates ([#4](https://github.com/lastmile-ai/lastmile-python/issues/4)) ([cac7caf](https://github.com/lastmile-ai/lastmile-python/commit/cac7caf774f9f35a14632ed5a26fa295b52fbdd8))
* **api:** manual updates ([#5](https://github.com/lastmile-ai/lastmile-python/issues/5)) ([eb3ec90](https://github.com/lastmile-ai/lastmile-python/commit/eb3ec90416dcac5299db02d4cd89a5c01742da3d))


### Bug Fixes

* **client:** avoid OverflowError with very large retry counts ([#4](https://github.com/lastmile-ai/lastmile-python/issues/4)) ([47d0fb2](https://github.com/lastmile-ai/lastmile-python/commit/47d0fb29f89f32d6fe59ee16228ea934bd502216))


### Chores

* add repr to PageInfo class ([8d0dde1](https://github.com/lastmile-ai/lastmile-python/commit/8d0dde1480e1eff8a43c89b10ce9399789787411))
* go live ([#1](https://github.com/lastmile-ai/lastmile-python/issues/1)) ([d1a9313](https://github.com/lastmile-ai/lastmile-python/commit/d1a9313a1041302aa553a751b2db3a1777721e9a))
* go live ([#1](https://github.com/lastmile-ai/lastmile-python/issues/1)) ([9e6fc92](https://github.com/lastmile-ai/lastmile-python/commit/9e6fc92ebec5b9e78b2c18938d50583d825a0188))
* update SDK settings ([2eba47f](https://github.com/lastmile-ai/lastmile-python/commit/2eba47ffaf5a53c54ec945a60cfa3f08e47812a0))
* update SDK settings ([#3](https://github.com/lastmile-ai/lastmile-python/issues/3)) ([1d43bb0](https://github.com/lastmile-ai/lastmile-python/commit/1d43bb0bda7d80b970b051425be1ab4a844a246f))
* update SDK settings ([#3](https://github.com/lastmile-ai/lastmile-python/issues/3)) ([e63c99b](https://github.com/lastmile-ai/lastmile-python/commit/e63c99b3a52e8eb5dc90900f91c32d65b1a747f5))
